@@ -50,6 +50,7 @@ actnw q|
 	$g = cos($cz*6.3)/2 + 0.5;
 	$b = $cz;
 	line3d [$cx,$cy,$cz], [$r,$g,$b];    # Draw a colored line
+	# [press 'q' in the graphics window when done]
 |;
 
 actnw q|
@@ -57,6 +58,7 @@ actnw q|
 	$y = (yvals zeroes $size+1,$size+1) / $size;
 	$z = 0.5 + 0.5 * (sin($x*6.3) * sin($y*6.3)) ** 3;   # Bumps
 	line3d [$x,$y,$z];	# Draw several lines
+	# [press 'q' in the graphics window when done]
 |;
 
 actnw q|
@@ -64,33 +66,40 @@ actnw q|
 	$g = $y;
 	$b = $z;
 	line3d [$x,$y,$z], [$r,$g,$b];	# Draw several colored lines
+	# [press 'q' in the graphics window when done]
 |;
 
 actnw q|
 	lattice3d [$x,$y,$z], [$r,$g,$b];  # Draw a colored lattice
+	# [press 'q' in the graphics window when done]
 |;
 
 actnw q|
-	points3d [$x,$y,$z], [$r,$g,$b];  # Draw colored points
+	points3d [$x,$y,$z], [$r,$g,$b], {PointSize=>4};  # Draw colored points
+	# [press 'q' in the graphics window when done]
 |;
 
 actnw q|
 	imag3d_ns [$x,$y,$z], [$r,$g,$b];  # Draw a colored surface
+	# [press 'q' in the graphics window when done]
 |;
 
 actnw q|
 	imag3d [$x,$y,$z]; # Draw a shaded surface
+	# [press 'q' in the graphics window when done]
 |;
 
 actnw q|
 	hold3d();	# Leave the previous object in..
 	imag3d_ns [$x,$y,$z+1], [$r,$g,$b];
 			# ...and draw a colored surface on top of it...
+	# [press 'q' in the graphics window when done]
 |;
 
 actnw q|
 	lattice3d [$x,$y,$z-1], [$r,$g,$b];
 			# ...and draw a colored lattice under it...
+	# [press 'q' in the graphics window when done]
 |;
 
 actnw q|
@@ -101,22 +110,25 @@ actnw q|
 	keeptwiddling3d();   # Do wait for user while drawing...
 	twiddle3d();	     # and actually, wait right now.
 	release3d();
+	# [press 'q' in the graphics window when done]
 |;
 
 actnw q|
 	# The reason for the [] around $x,$y,$z:
-	# 1. You can give all the coordinates and colors in one piddle.
+	# 1. You can give all the coordinates and colors in one ndarray.
 	$c = (zeroes 3,$size+1) / $size;
 	$coords =
 		sin((3+3*xvals $c)*yvals $c);
 	$colors = $coords;
 	line3d $coords, $colors;        # Draw a curved line, colored
 					# (this works also for lattices, etc.)
+	# [press 'q' in the graphics window when done]
 |;
 
 actnw q|
 	# 2. You can use defaults inside the brackets:
 	lattice3d [$z], [$r];  # Note: no $x, $y, and $r is greyscale
+	# [press 'q' in the graphics window when done]
 |;
 
 actnw q|
@@ -124,11 +136,13 @@ actnw q|
 	imag3d_ns [POLAR2D, $z], [$r, $g, $b];  # Draw the familiar
 						# bumpy surface in polar
 						# coordinates
+	# [press 'q' in the graphics window when done]
 |;
 
 actnw q|
 	# One last thing: you can plot a color image like this
 	imagrgb([$r,$g,$b]);
+	# [press 'q' in the graphics window when done]
 |;
 
 comment q|
